@@ -40,14 +40,14 @@ class TrunkSerializer(TagSerializer, serializers.ModelSerializer):
 
 class UCClusterSerializer(TagSerializer, serializers.ModelSerializer):
 
-    label = serializers.CharField(source='UCCluster', read_only=True)
+    label = serializers.CharField(source='uccluster', read_only=True)
     tenant = NestedTenantSerializer(required=True, allow_null=False)
     tags = NestedTagSerializer(many=True, required=False)
 
     class Meta:
         model = UCCluster
         fields = [
-            "id", "label", "UCCluster", "tenant", "publisher", "subscriber1", "subscriber2", "subscriber3", "subscriber4", "tftp1", "tftp2", "description", "tags"
+            "id", "label", "uccluster", "tenant", "publisher", "subscriber1", "subscriber2", "subscriber3", "subscriber4", "tftp1", "tftp2", "description", "tags"
         ]
 
 class DevicePoolSerializer(TagSerializer, serializers.ModelSerializer):
