@@ -289,7 +289,7 @@ class UCClusterEditForm(BootstrapMixin, forms.ModelForm):
 
     class Meta:
         model = UCCluster
-        fields = ('UCCluster', 'tenant', 'description', 'publisher', 'subscriber1', 'subscriber2', 'subscriber3', 'subscriber4', 'tftp1', 'tftp2')
+        fields = ('uccluster', 'tenant', 'description', 'publisher', 'subscriber1', 'subscriber2', 'subscriber3', 'subscriber4', 'tftp1', 'tftp2')
 
 
 class UCClusterBulkEditForm(BootstrapMixin, AddRemoveTagsForm, BulkEditForm):
