@@ -111,7 +111,7 @@ class Number(ChangeLoggedModel):
 
 
 class UCCluster(ChangeLoggedModel):
-    UCCluster = models.CharField(max_length=200)
+    uccluster = models.CharField(max_length=200)
     description = models.CharField(max_length=200)
     tags = TaggableManager(through=TaggedItem)
     tenant = models.ForeignKey(
@@ -130,16 +130,16 @@ class UCCluster(ChangeLoggedModel):
 
     objects = RestrictedQuerySet.as_manager()
 
-    csv_headers = ['UCCluster', 'tenant', 'description', 'publisher', 'subscriber1', 'subscriber2', 'subscriber3', 'subscriber4', 'tftp1', 'tftp2']
+    csv_headers = ['uccluster', 'tenant', 'description', 'publisher', 'subscriber1', 'subscriber2', 'subscriber3', 'subscriber4', 'tftp1', 'tftp2']
 
     def __str__(self):
-        return str(self.UCCluster)
+        return str(self.uccluster)
 
     def get_absolute_url(self):
-        return reverse("plugins:ucbox_plugin:UCCluster_view", kwargs={"pk": self.pk})
+        return reverse("plugins:ucbox_plugin:uccluster_view", kwargs={"pk": self.pk})
 
     class Meta:
-        unique_together = ("UCCluster", "tenant",)#ermoe enant here
+        unique_together = ("uccluster", "tenant",)#ermoe enant here
 
 
 
